@@ -1,7 +1,7 @@
 ;; -*- mode: scheme; coding: utf-8 -*-
 
 ;;;;
-;;;; Copyright (C) 2011 - 2016
+;;;; Copyright (C) 2011 - 2018
 ;;;; David Pirotte <david at altosw dot be>
 
 ;;;; This file is part of Grip.
@@ -42,27 +42,33 @@
   #:use-module (gnome-2)
   #:use-module (gnome gobject)
   #:use-module (gnome clutter)
-  #:use-module (grip g-export)
+  #:use-module (grip module)
   #:use-module (grip goops)
   #:use-module (grip utils)
-  #:use-module (grip keyword)
-  #:use-module (grip lists)
-  #:use-module (grip nbs)
-  #:use-module (grip strings)
-  #:use-module (grip clutter colour)
+  #:use-module (grip optargs)
+  #:use-module (grip list)
+  #:use-module (grip number)
+  #:use-module (grip string)
+  #:use-module (grip clutter color)
   #:use-module (grip clutter globals)
   #:use-module (grip clutter constraint)
   #:use-module (grip clutter gravity)
   #:use-module (grip clutter orientation)
   #:use-module (grip clutter actor)
 
+  #:duplicates (merge-generics
+		replace
+		warn-override-core
+		warn
+		last)
+
   #:export (<clus-apple>))
 
 
 (g-export get-orientation
 	  set-orientation
 	  
-	  !colour
+	  !color
 	  !layout
 	  !orientation
 	  !x-align
@@ -106,8 +112,8 @@
 ;;;
 
 (define-class <clus-apple> (<clutter-actor>)
-  (colour #:accessor !colour
-	  #:init-keyword #:colour
+  (color #:accessor !color
+	  #:init-keyword #:color
 	  #:allocation #:virtual
 	  #:slot-ref (lambda (self)
 		       (get-background-color self))
@@ -225,22 +231,22 @@
 
 (define-method (initialize (self <clus-apple>) initargs)
   #;(dimfi "initialize <clus-apple>" initargs)
-  (receive (kw virtual-kw)
-      (split-keyword-args initargs
-			  (map slot-definition-init-keyword
-			    (class-direct-virtual-slots <clus-apple>)))
+  (receive (virtual-kw rest)
+      (split-keyword-args (map slot-definition-init-keyword
+			    (class-direct-virtual-slots <clus-apple>))
+                          initargs)
     (if (null? virtual-kw)
-	(next-method)
+	(next-method self rest)
 	(begin
-	  (next-method self kw)
+	  (next-method self rest)
 	  (let-keywords virtual-kw #t
-			((colour #f)
+			((color #f)
 			 (x-align #f)
 			 (y-align #f)
 			 (x-expand #f)
 			 (y-expand #f))
-			(when colour
-			  (set! (!colour self) colour))
+			(when color
+			  (set! (!color self) color))
 			(when x-align
 			  (set! (!x-align self) x-align))
 			(when y-align
@@ -263,8 +269,8 @@
 			    (format #f "~S" (slot-ref self name))
 			    "#<unbound>"))))
       (filter-map (lambda (slot)
-		    (and (str/contains? (symbol->string (slot-definition-name slot))
-					"gravity")
+		    (and (string-contains (symbol->string (slot-definition-name slot))
+                                          "gravity")
 			 slot))
 	  (class-direct-slots <clus-apple>)))
   (format #t "  margins are:~%")
@@ -456,9 +462,9 @@ must ba a value between " *clus-gravity-resistance-min* "and" *clus-gravity-resi
 				 *clus-gravity-resistance-normalization-quotient*)))
 		(case which
 		  ((north)
-		   (fp/round (* n-factor ph) 3))
+		   (float-round (* n-factor ph) 3))
 		  ((west)
-		   (fp/round (* n-factor pw) 3)))))
+		   (float-round (* n-factor pw) 3)))))
 	    (clus-warning-invalid-resistance-factor factor))
 	(clus-warning-no-parent self))))
 
@@ -481,7 +487,7 @@ must ba a value between " *clus-gravity-resistance-min* "and" *clus-gravity-resi
 	#;(dimfi "  " (list-insert
 		     '(new prev-north prev-west min max set-to)
 		     ;; clutter sometimes returns far too many decimals
-		     (map fp/round
+		     (map float-round
 		       (list new prev-north prev-west min-margin max-margin margin))))
 	(case which
 	  ((north)
