@@ -1,7 +1,7 @@
 ;; -*- mode: scheme; coding: utf-8 -*-
 
 ;;;;
-;;;; Copyright (C) 2011 - 2016
+;;;; Copyright (C) 2011 - 2018
 ;;;; David Pirotte <david at altosw dot be>
 
 ;;;; This file is part of Grip.
@@ -38,6 +38,12 @@
   #:use-module (gnome gobject)
   #:use-module (gnome clutter)
 
+  #:duplicates (merge-generics
+		replace
+		warn-override-core
+		warn
+		last)
+
   #:export (%clus-orientation
 	    clus-orientation?))
 
