@@ -1,7 +1,7 @@
 ;; -*- mode: scheme; coding: utf-8 -*-
 
 ;;;;
-;;;; Copyright (C) 2011 - 2016
+;;;; Copyright (C) 2011 - 2018
 ;;;; David Pirotte <david at altosw dot be>
 
 ;;;; This file is part of Grip.
@@ -36,10 +36,10 @@
   #:use-module (ice-9 format)
   #:use-module (ice-9 rdelim)
   #:use-module (ice-9 popen)
-  #:use-module (grip reexport)
+  #:use-module (grip module)
   #:use-module (grip db sqlite3)
-  #:use-module (grip strings)
-  #:use-module (grip lists)
+  #:use-module (grip string)
+  #:use-module (grip list)
 
   #:export (sqlite/get
 	    sqlite/set
@@ -84,12 +84,12 @@
 			      (ice-9 rdelim)
 			      (ice-9 popen)
 			      (grip db sqlite3)
-			      (grip strings)
-			      (grip lists)))
+			      (grip string)
+			      (grip list)))
 
 
 (define (sqlite/sqlite-db-file? filename)
-  (let* ((cmd (format #f "file ~A" (str/prep-str-for-fs filename)))
+  (let* ((cmd (format #f "file ~A" (string-escape-filename filename)))
 	 (port (open-input-pipe cmd))
 	 (str (read-line port)))
     (unless (zero? (status:exit-val (close-pipe port)))
