@@ -1,7 +1,7 @@
 ;; -*- mode: scheme; coding: utf-8 -*-
 
 ;;;;
-;;;; Copyright (C) 2011 - 2016
+;;;; Copyright (C) 2011 - 2018
 ;;;; David Pirotte <david at altosw dot be>
 
 ;;;; This file is part of Grip.
@@ -28,12 +28,13 @@
 
 (define-module (grip gnome)
   #:use-module (oop goops)
-  #:use-module (grip reexport)
-  #:use-module (grip gnome colours)
+  #:use-module (grip module)
+  #:use-module (grip gnome store)
+  #:use-module (grip gnome color)
   #:use-module (grip gnome key-press)
   #:use-module (grip gnome gtk2)
   #:use-module (grip gnome filechooser)
-  #:use-module (grip gnome mdialogs)
+  #:use-module (grip gnome mdialog)
 
   #:duplicates (merge-generics
 		replace
@@ -44,8 +45,9 @@
 
 (eval-when (expand load eval)
   (re-export-public-interface (oop goops)
-			      (grip gnome colours)
+                              (grip gnome store)
+			      (grip gnome color)
 			      (grip gnome key-press)
 			      (grip gnome gtk2)
 			      (grip gnome filechooser)
-			      (grip gnome mdialogs)))
+			      (grip gnome mdialog)))
