@@ -1,7 +1,7 @@
 ;; -*- mode: scheme; coding: utf-8 -*-
 
 ;;;;
-;;;; Copyright (C) 2011 - 2016
+;;;; Copyright (C) 2011 - 2018
 ;;;; David Pirotte <david at altosw dot be>
 
 ;;;; This file is part of Grip.
@@ -38,9 +38,8 @@
   #:use-module (gnome-2)
   #:use-module (gnome gobject)
   #:use-module (gnome gtk)
-  #:use-module (grip reexport)
-  #:use-module (grip g-export)
-  #:use-module (grip do)
+  #:use-module (grip module)
+  #:use-module (grip iter)
 
   #:duplicates (merge-generics
 		replace
@@ -75,7 +74,7 @@
 			      (oop goops)
 			      (gnome gobject)
 			      (gnome gtk)
-			      (grip do)))
+			      (grip iter)))
 
 
 ;;;
