@@ -1,7 +1,7 @@
 ;; -*- mode: scheme; coding: utf-8 -*-
 
 ;;;;
-;;;; Copyright (C) 2011 - 2016
+;;;; Copyright (C) 2011 - 2018
 ;;;; David Pirotte <david at altosw dot be>
 
 ;;;; This file is part of Grip.
@@ -39,8 +39,9 @@
   #:use-module (gnome gobject)
   #:use-module (gnome glade)
   #:use-module (gnome gtk)
-  #:use-module (grip reexport)
+  #:use-module (grip module)
   #:use-module (grip utils)
+  #:use-module (grip gnome store)
   #:use-module (grip gnome gtk2)
 
   #:duplicates (merge-generics
@@ -59,10 +60,8 @@
 			      (gnome glade)
 			      (gnome gobject)
 			      (grip utils)
-			      (grip gnome gtk2))
-  (unless (storage-get 'mdgladefile)
-    (let ((gripgnomedir (dirname (search-path %load-path "grip/gnome/mdialog-2b.scm"))))
-      (storage-set 'mdgladefile (string-append gripgnomedir "/glade/mdialogs.glade")))))
+                              (grip gnome store)
+			      (grip gnome gtk2)))
 
 
 ;;;
@@ -87,7 +86,7 @@
   (cancel-callback #:accessor cancel-callback #:init-keyword #:cancel-callback #:init-value #'identity))
 
 (define (md2b/make-dialog)
-  (let* ((xml (glade-xml-new (storage-get 'mdgladefile) #f "md2b"))
+  (let* ((xml (glade-xml-new (ref %gnome-store 'mdgladefile) #f "md2b"))
 	 (md2b-dialog (get-widget xml "md2b"))
 	 (img (get-widget xml "md2b/image"))
 	 (lb (get-widget xml "md2b/label"))
