@@ -1,7 +1,7 @@
 ;; -*- mode: scheme; coding: utf-8 -*-
 
 ;;;;
-;;;; Copyright (C) 2011 - 2016
+;;;; Copyright (C) 2011 - 2018
 ;;;; David Pirotte <david at altosw dot be>
 
 ;;;; This file is part of Grip.
@@ -23,24 +23,31 @@
 
 ;;; Commentary:
 
-;; The describe method is defined somewhere in gops and in guile-gnome,
-;; and I can't remember now why, but I was not satisfied with their
-;; respective definition, so here is Grip's version.
+;; define-method* has been written by Mark H Weaver, I just changed
+;; let-values -> receive, which I find (a lot) more readable. I can't
+;; point to 'an original definition location' though, because Mark
+;; pasted his definition while chating on #guile, a few years ago.  I
+;; don't think Mark ever published this code anywhere, but I could be
+;; wrong, if that is the case, please let me know, I'd be happy to add
+;; the link here.
 
 ;;; Code:
 
 
 (define-module (grip goops)
+  #:use-module (ice-9 receive)
   #:use-module (srfi srfi-1)
   #:use-module (oop goops)
-  #:use-module (grip reexport)
-  #:use-module (grip g-export)
+  #:use-module (oop goops describe)
+  #:use-module (grip module)
 
   #:duplicates (merge-generics
 		replace
 		warn-override-core
 		warn
-		last))
+		last)
+
+  #:export (define-method*))
 
 
 (g-export class-direct-virtual-slots
@@ -52,31 +59,28 @@
   (re-export-public-interface (oop goops)))
 
 
-(define-method (class-direct-virtual-slots (c <class>))
+(define-syntax define-method*
+  (lambda (x)
+    (syntax-case x ()
+      ((_ (generic arg-spec ... . tail) body ...)
+       (receive (required-arg-specs other-arg-specs)
+           (break (compose keyword? syntax->datum)
+                  #'(arg-spec ...))
+         #`(define-method (generic #,@required-arg-specs . rest)
+             (apply (lambda* (#,@other-arg-specs . tail)
+                      body ...)
+                    rest)))))))
+
+(define-method (class-direct-virtual-slots (class <class>))
   (filter-map (lambda (slot-definition)
 		(and (eq? (slot-definition-allocation slot-definition)
 			  #:virtual)
 		     slot-definition))
-      (class-direct-slots c)))
+      (class-direct-slots class)))
 
-(define-method (class-virtual-slots (c <class>))
+(define-method (class-virtual-slots (class <class>))
   (filter-map (lambda (slot-definition)
 		(and (eq? (slot-definition-allocation slot-definition)
 			  #:virtual)
 		     slot-definition))
-      (class-slots c)))
-
-(define-method (describe (self <object>))
-  (format #t "~S - instance of ~A~%"
-	  self
-	  (class-name (class-of self)))
-  (format #t "  slots and values are:~%")
-  (for-each (lambda (slot)
-	      (let ((name (slot-definition-name slot)))
-		(format #t "    ~S = ~A~%"
-			name
-			(if (slot-bound? self name) 
-			    (format #f "~S" (slot-ref self name))
-			    "#<unbound>"))))
-	    (class-slots (class-of self)))
-  *unspecified*)
+      (class-slots class)))
