@@ -1,7 +1,7 @@
 ;; -*- mode: scheme; coding: utf-8 -*-
 
 ;;;;
-;;;; Copyright (C) 2011 - 2016
+;;;; Copyright (C) 2011 - 2018
 ;;;; David Pirotte <david at altosw dot be>
 
 ;;;; This file is part of Grip.
@@ -27,7 +27,7 @@
 
 
 (define-module (grip sqlite)
-  #:use-module (grip reexport)
+  #:use-module (grip module)
   #:use-module (grip db sqlite3)
   #:use-module (grip db sqlite))
 
